summaryrefslogtreecommitdiffstats
path: root/libdvdnav
diff options
context:
space:
mode:
Diffstat (limited to 'libdvdnav')
-rw-r--r--libdvdnav/decoder.c10
-rw-r--r--libdvdnav/dvdnav.h8
-rw-r--r--libdvdnav/settings.c6
-rw-r--r--libdvdnav/vm.c8
4 files changed, 16 insertions, 16 deletions
diff --git a/libdvdnav/decoder.c b/libdvdnav/decoder.c
index 007fe35..1c21f60 100644
--- a/libdvdnav/decoder.c
+++ b/libdvdnav/decoder.c
@@ -35,7 +35,7 @@
uint32_t vm_getbits(command_t *command, int32_t start, int32_t count) {
uint64_t result = 0;
- uint64_t bit_tqmask = 0;
+ uint64_t bit_mask = 0;
uint64_t examining = 0;
int32_t bits;
@@ -50,12 +50,12 @@ uint32_t vm_getbits(command_t *command, int32_t start, int32_t count) {
abort();
}
/* all ones, please */
- bit_tqmask = ~bit_tqmask;
- bit_tqmask >>= 63 - start;
+ bit_mask = ~bit_mask;
+ bit_mask >>= 63 - start;
bits = start + 1 - count;
- examining = ((bit_tqmask >> bits) << bits );
+ examining = ((bit_mask >> bits) << bits );
command->examined |= examining;
- result = (command->instruction & bit_tqmask) >> bits;
+ result = (command->instruction & bit_mask) >> bits;
return (uint32_t) result;
}
diff --git a/libdvdnav/settings.c b/libdvdnav/settings.c
index a760b96..4af8aea 100644
--- a/libdvdnav/settings.c
+++ b/libdvdnav/settings.c
@@ -29,7 +29,7 @@
/* Characteristics/setting API calls */
-dvdnav_status_t dvdnav_get_region_tqmask(dvdnav_t *this, int32_t *region) {
+dvdnav_status_t dvdnav_get_region_mask(dvdnav_t *this, int32_t *region) {
if(!this || !region) {
printerr("Passed a NULL this pointer.");
return DVDNAV_STATUS_ERR;
@@ -39,14 +39,14 @@ dvdnav_status_t dvdnav_get_region_tqmask(dvdnav_t *this, int32_t *region) {
return DVDNAV_STATUS_OK;
}
-dvdnav_status_t dvdnav_set_region_tqmask(dvdnav_t *this, int32_t tqmask) {
+dvdnav_status_t dvdnav_set_region_mask(dvdnav_t *this, int32_t mask) {
if(!this) {
printerr("Passed a NULL this pointer.");
return DVDNAV_STATUS_ERR;
}
pthread_mutex_lock(&this->vm_lock);
- this->vm->state.registers.SPRM[20] = (tqmask & 0xff);
+ this->vm->state.registers.SPRM[20] = (mask & 0xff);
pthread_mutex_unlock(&this->vm_lock);
return DVDNAV_STATUS_OK;
}
diff --git a/libdvdnav/vm.c b/libdvdnav/vm.c
index 0df5f0b..dbebafa 100644
--- a/libdvdnav/vm.c
+++ b/libdvdnav/vm.c
@@ -359,11 +359,11 @@ int vm_reset(vm_t *vm, const char *dvdroot) {
/* ifoRead_TXTDT_MGI(vmgi); Not implemented yet */
}
if (vm->vmgi) {
- int i, tqmask;
- fprintf(MSG_OUT, "libdvdnav: DVD disk reports itself with Region tqmask 0x%08x. Regions:",
+ int i, mask;
+ fprintf(MSG_OUT, "libdvdnav: DVD disk reports itself with Region mask 0x%08x. Regions:",
vm->vmgi->vmgi_mat->vmg_category);
- for (i = 1, tqmask = 1; i <= 8; i++, tqmask <<= 1)
- if (((vm->vmgi->vmgi_mat->vmg_category >> 16) & tqmask) == 0)
+ for (i = 1, mask = 1; i <= 8; i++, mask <<= 1)
+ if (((vm->vmgi->vmgi_mat->vmg_category >> 16) & mask) == 0)
fprintf(MSG_OUT, " %d", i);
fprintf(MSG_OUT, "\n");
}
diff --git a/libdvdnav/dvdnav.h b/libdvdnav/dvdnav.h
index b8618d9..b9812ad 100644
--- a/libdvdnav/dvdnav.h
+++ b/libdvdnav/dvdnav.h
@@ -120,22 +120,22 @@ int64_t dvdnav_convert_time(dvd_time_t *time);
*/
/*
* Sets the region tqmask (bit 0 set implies region 1, bit 1 set implies
* region 2, etc) of the virtual machine. Generally you will only need to set
* this if you are playing RCE discs which query the virtual machine as to its
* region setting.
*
* This has _nothing_ to do with the region setting of the DVD drive.
*/
-dvdnav_status_t dvdnav_set_region_tqmask(dvdnav_t *self, int32_t region_tqmask);
+dvdnav_status_t dvdnav_set_region_mask(dvdnav_t *self, int32_t region_mask);
/*
* Returns the region tqmask (bit 0 set implies region 1, bit 1 set implies
* region 2, etc) of the virtual machine.
*
* This has _nothing_ to do with the region setting of the DVD drive.
*/
-dvdnav_status_t dvdnav_get_region_tqmask(dvdnav_t *self, int32_t *region_tqmask);
+dvdnav_status_t dvdnav_get_region_mask(dvdnav_t *self, int32_t *region_mask);
/*
* Specify whether read-ahead caching should be used. You may not want this if your
@@ -120,22 +120,22 @@ int64_t dvdnav_convert_time(dvd_time_t *time);
*/
/*
- * Sets the region tqmask (bit 0 set implies region 1, bit 1 set implies
+ * Sets the region mask (bit 0 set implies region 1, bit 1 set implies
* region 2, etc) of the virtual machine. Generally you will only need to set
* this if you are playing RCE discs which query the virtual machine as to its
@@ -120,22 +120,22 @@ int64_t dvdnav_convert_time(dvd_time_t *time);
/*
- * Returns the region tqmask (bit 0 set implies region 1, bit 1 set implies
+ * Returns the region mask (bit 0 set implies region 1, bit 1 set implies
* region 2, etc) of the virtual machine.
*